/*
 *   LADCCA
 *    
 *   Copyright (C) 2002 Robert Ham (node@users.sourceforge.net)
 *    
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __LADCCAD_SERVER_EVENT_H__
#define __LADCCAD_SERVER_EVENT_H__

#include <uuid/uuid.h>

#include <ladcca/ladcca.h>
#include <ladcca/comm.h>

enum Server_Event_Type
{
  Client_Connect = 1,
  Client_Disconnect,
  Client_Event,
  Client_Config,
  Client_Comm_Event
};

typedef struct _server_event server_event_t;

struct _server_event
{
  enum Server_Event_Type    type;
  unsigned long             conn_id;
  union
  {
    cca_client_t *          cca_client;
    cca_event_t *           cca_event;
    cca_config_t *          cca_config;
    cca_comm_event_t *      cca_comm_event;
/*    uuid_t                  client_id */
  } data;
};

void server_event_init (server_event_t * event);
void server_event_free (server_event_t * event);

server_event_t * server_event_new ();
void             server_event_destroy ();

void server_event_set_type           (server_event_t * event, enum Server_Event_Type type);
void server_event_set_conn_id        (server_event_t * event, unsigned long id);
/*void server_event_set_client_id      (server_event_t * event, uuid_t id); */
void server_event_set_cca_event      (server_event_t * event, cca_event_t * cca_event);
void server_event_set_cca_client     (server_event_t * event, cca_client_t * cca_client);
void server_event_set_cca_config     (server_event_t * event, cca_config_t * cca_config);
void server_event_set_cca_comm_event (server_event_t * event, cca_comm_event_t * cca_comm_event);

enum Server_Event_Type   server_event_get_type            (const server_event_t * event);
unsigned long            server_event_get_conn_id         (const server_event_t * event);
/*void                     server_event_get_client_id       (const server_event_t * event, uuid_t id); */
const cca_event_t *      server_event_get_cca_event       (const server_event_t * event);
cca_event_t *            server_event_take_cca_event      (server_event_t * event);
const cca_client_t *     server_event_get_cca_client      (const server_event_t * event);
cca_client_t *           server_event_take_cca_client     (server_event_t * event);
const cca_config_t *     server_event_get_cca_config      (const server_event_t * event);
cca_config_t *           server_event_take_cca_config     (server_event_t * event);
const cca_comm_event_t * server_event_get_cca_comm_event  (const server_event_t * event);
cca_comm_event_t *       server_event_take_cca_comm_event (server_event_t * event);

#endif /* __LADCCAD_SERVER_EVENT_H__ */
